@@ -1,10 +1,10 @@
 test_that("prepare_inj works", {
   df_injuries <- prepare_inj(df_injuries0   = raw_df_injuries,
-                             player         = "player_name",
+                             person_id      = "player_name",
                              date_injured   = "from",
                              date_recovered = "until")
 
-  expect_equal(is.data.frame(df_injuries), TRUE)
+  expect_data_frame(df_injuries, nrows = 82L, ncols = 11L)
   expect_data_frame(df_injuries,
                     nrow = nrow(raw_df_injuries), ncol = ncol(raw_df_injuries))
   expect_identical(class(df_injuries[["date_injured"]]), "Date")
@@ -12,7 +12,7 @@ test_that("prepare_inj works", {
 
   raw_df_injuries$until[[1]] <- raw_df_injuries$from[[1]] - 2
   expect_error(prepare_inj(df_injuries0   = raw_df_injuries,
-                           player         = "player_name",
+                           person_id      = "player_name",
                            date_injured   = "from",
                            date_recovered = "until"),
                "date_recovered should be")
@@ -21,11 +21,11 @@ test_that("prepare_inj works", {
 
 test_that("prepare_exp works", {
   df_exposures <- prepare_exp(df_exposures0 = raw_df_exposures,
-                              player        = "player_name",
+                              person_id     = "player_name",
                               date          = "year",
                               time_expo     = "minutes_played")
 
-  expect_equal(is.data.frame(df_exposures), TRUE)
+  expect_data_frame(df_exposures, nrows = 42L, ncols = 19L)
   expect_data_frame(df_exposures,
                     nrow = nrow(raw_df_exposures), ncol = ncol(raw_df_exposures))
   expect_subset(class(df_exposures[["date"]]), c("Date", "numeric"))
@@ -33,7 +33,7 @@ test_that("prepare_exp works", {
 
   raw_df_exposures$year[[1]] <- 202
   expect_error(prepare_exp(df_exposures0 = raw_df_exposures,
-                           player        = "player_name",
+                           person_id     = "player_name",
                            date          = "year",
                            time_expo     = "minutes_played"),
                "it must refer to the year")
@@ -42,11 +42,11 @@ test_that("prepare_exp works", {
 
 test_that("prepare_all works", {
   df_injuries <- prepare_inj(df_injuries0   = raw_df_injuries,
-                             player         = "player_name",
+                             person_id      = "player_name",
                              date_injured   = "from",
                              date_recovered = "until")
   df_exposures <- prepare_exp(df_exposures0 = raw_df_exposures,
-                              player        = "player_name",
+                              person_id     = "player_name",
                               date          = "year",
                               time_expo     = "minutes_played")
 
@@ -55,13 +55,11 @@ test_that("prepare_all works", {
                                        exp_unit = "matches_minutes"))
   expect_equal(is.data.frame(injd), TRUE)
   expect_s3_class(injd, "injd")
-  expect_subset(c("player", "t0", "tf", "date_injured", "date_recovered",
+  expect_subset(c("person_id", "t0", "tf", "date_injured", "date_recovered",
                   "tstart", "tstop", "status", "enum"),
                 names(injd))
+  expect_data_frame(data.frame(injd), nrows = 108L, ncols = 19L)
   expect_type(attr(injd, "unit_exposure"), "character")
-  expect_equal(is.data.frame(attr(injd, "follow_up")), TRUE)
-  expect_equal(is.data.frame(attr(injd, "data_exposures")), TRUE)
-  expect_equal(is.data.frame(attr(injd, "data_injuries")), TRUE)
   expect_equal(is_injd(injd), TRUE)
 
   expect_error(prepare_all(data_exposures = df_exposures,
@@ -72,11 +70,11 @@ test_that("prepare_all works", {
 
 test_that("prepare_all works fine when dates in injury and exposure data do not match", {
   df_injuries <- prepare_inj(df_injuries0   = raw_df_injuries,
-                             player         = "player_name",
+                             person_id      = "player_name",
                              date_injured   = "from",
                              date_recovered = "until")
   df_exposures <- prepare_exp(df_exposures0 = raw_df_exposures,
-                              player        = "player_name",
+                              person_id     = "player_name",
                               date          = "year",
                               time_expo     = "minutes_played")
 
@@ -92,7 +90,7 @@ test_that("prepare_all works fine when dates in injury and exposure data do not
 
 test_that("data_followup works as expected", {
   df_exposures <- prepare_exp(df_exposures0 = raw_df_exposures,
-                              player        = "player_name",
+                              person_id     = "player_name",
                               date          = "year",
                               time_expo     = "minutes_played")
 
